==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetCampaignVersionRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCampaignVersionRequest(
    applicationId: __string,
    campaignId: __string,
    version: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest = {
    import GetCampaignVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .campaignId(__string.unwrap(campaignId): java.lang.String)
      .version(__string.unwrap(version): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignVersionRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignVersionRequest.wrap(buildAwsValue())
}
object GetCampaignVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignVersionRequest =
      zio.aws.pinpoint.model
        .GetCampaignVersionRequest(applicationId, campaignId, version)
    def applicationId: __string
    def campaignId: __string
    def version: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getCampaignId: ZIO[Any, Nothing, __string] = ZIO.succeed(campaignId)
    def getVersion: ZIO[Any, Nothing, __string] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
  ) extends zio.aws.pinpoint.model.GetCampaignVersionRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val campaignId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.campaignId())
    override val version: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.version())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
  ): zio.aws.pinpoint.model.GetCampaignVersionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetCampaignVersionRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCampaignVersionRequest(
    applicationId: __string,
    campaignId: __string,
    version: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest = {
    import GetCampaignVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .campaignId(campaignId: java.lang.String)
      .version(version: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignVersionRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignVersionRequest.wrap(buildAwsValue())
}
object GetCampaignVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignVersionRequest =
      zio.aws.pinpoint.model
        .GetCampaignVersionRequest(applicationId, campaignId, version)
    def applicationId: __string
    def campaignId: __string
    def version: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getCampaignId: ZIO[Any, Nothing, __string] = ZIO.succeed(campaignId)
    def getVersion: ZIO[Any, Nothing, __string] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
  ) extends zio.aws.pinpoint.model.GetCampaignVersionRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val campaignId: __string = impl.campaignId(): __string
    override val version: __string = impl.version(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignVersionRequest
  ): zio.aws.pinpoint.model.GetCampaignVersionRequest.ReadOnly = new Wrapper(
    impl
  )
}
